==> ilias-3.7.3_1.tbz: www/ilias/Services/Tracking/classes/ItemList/class.ilLPTestListGUI.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2001 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/

/**
* Class ilLPItemListGUI
*
* @author Stefan Meyer <smeyer@databay.de>
*
* @version $Id: class.ilLPTestListGUI.php,v 1.1.2.2 2006/10/06 10:53:41 smeyer Exp $
*
* @extends ilObjectGUI
* @package ilias-core
*
*/

include_once 'Services/Tracking/classes/ItemList/class.ilLPObjectItemListGUI.php';

class ilLPTestListGUI extends ilLPObjectItemListGUI
{
	function ilLPTestListGUI($a_obj_id)
	{
		parent::ilLPObjectItemListGUI($a_obj_id,'tst');

		$this->__readAnonymized();
	}


	function __readAnonymized()
	{
		include_once 'assessment/classes/class.ilObjTest.php';
		if(ilObjTest::_lookupTestType($this->getId()) == TYPE_SELF_ASSESSMENT)
		{
			$this->anonymized = true;
		}

	}
		
}
?>

==> ilias-3.9.6.tbz: www/ilias/Services/Tracking/classes/ItemList/class.ilLPTestListGUI.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2001 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/

/**
* Class ilLPItemListGUI
*
* @author Stefan Meyer <smeyer@databay.de>
*
* @version $Id: class.ilLPTestListGUI.php 12483 2006-11-09 10:05:31Z hschottm $
*
* @extends ilObjectGUI
* @package ilias-core
*
*/

include_once 'Services/Tracking/classes/ItemList/class.ilLPObjectItemListGUI.php';

class ilLPTestListGUI extends ilLPObjectItemListGUI
{
	function ilLPTestListGUI($a_obj_id)
	{
		parent::ilLPObjectItemListGUI($a_obj_id,'tst');

		$this->__readAnonymized();
	}


	function __readAnonymized()
	{
		include_once './Modules/Test/classes/class.ilObjTest.php';
		if(ilObjTest::_lookupAnonymity($this->getId()))
		{
			$this->anonymized = true;
		}

	}
		
}
?>
